import pygame, sys, os, math
from pygame.locals import *
import student_code

### Functions to draw the scene
def draw_square(arena,targetPosX,targetPosY,color=(0,0,0),size = 10):
    """draws a rectangle on the screen"""
    target = pygame.Rect(targetPosX-(size/float(2)), targetPosY-(size/float(2)), size, size) #create the rectangle
    pygame.draw.rect(arena, color, target) #Draw it on the screen
    
def draw_arrow(arena,startPosX,startPosY,targetPosX,targetPosY,width=3,color=(0,0,0)):
    pygame.draw.line(arena, color,(startPosX,startPosY),(targetPosX,targetPosY),width) #Draw it on the screen

def write_text(arena,myText,posX,posY,fontSize=24):
    font = pygame.font.Font('freesansbold.ttf', fontSize)
    text = font.render(myText, True, (0,0,0), (255,255,255))
    textRect = text.get_rect()
    textRect.center = (posX,posY)
    arena.blit(text, textRect)
    
    
### Calculates an y value on a circle given an x value
def calculate_circle_position(origin_x,origin_y,posX,radius=400):
    xdev = posX-origin_x
    ydev = math.sqrt(radius*radius-xdev*xdev)
    return origin_y-ydev
    
    
    
#Initial Position and Rotation of the Player
#Change these during the loop to update the players Position    
origin_x = 50 
origin_y = 550
playerHeading = 0
radius=400

#A list of possible target positions
target_x_list = [50,100,150,200,250,300,350,400,420,430,450]
target_num = 0 #Current active target
target_y_list = []
for xPos in target_x_list:
    yPos = calculate_circle_position(origin_x,origin_y,xPos,radius)
    target_y_list.append(yPos)

pygame.init() #Initialize the pygame module
screen = pygame.display.set_mode((800, 600)) #Define a 800,600 screen

while True: #The pygame Loop runs forever
    for event in pygame.event.get(): #This loop makes sure that the X-Button works!
            if event.type == QUIT:
                pygame.quit() #Quit the game in case of x-button press
                sys.exit()


    screen.fill((255,255,255)) # In each loop we will redraw the screen
    
    
    # This part cycles through the different target positions
    targetPosX = target_x_list[target_num] #Select target_num x Value
    targetPosY = target_y_list[target_num] #Select target_num y Value
    target_num = (target_num +1) % len(target_x_list) #Increase target_num. Use modulo to keep it between 0 and the last target
    
    # Draw a square at the target position with size 10 and blue color
    draw_square(screen,targetPosX,targetPosY,(228,29,16),10) 
    #Draw vectors and agle
    draw_arrow(screen,origin_x,origin_y,targetPosX,targetPosY)
    draw_arrow(screen,origin_x,origin_y,450,550,5,(23,93,102))
    draw_arrow(screen,targetPosX,targetPosY,targetPosX,origin_y,1,(228,29,16))
    pygame.draw.arc(screen,(0,0,0),(origin_x-40,origin_y-40,80,80),0,math.asin((origin_y-targetPosY)/radius),4)
   
    #Draw labels
    write_text(screen,"Vector A",targetPosX-80,targetPosY+30,16)
    write_text(screen,"Hypothenuse",targetPosX-100,targetPosY+50,16)
    write_text(screen,"Opposite Kathete",targetPosX+60,origin_y-((origin_y-targetPosY)/2),16)
    write_text(screen,"Vector B",origin_x+radius+40,origin_y,16)
    write_text(screen,"("+"{:5.2f}".format(targetPosX)+","+"{:5.2f}".format(targetPosY)+")",targetPosX+20,targetPosY-20,16)
    

    ####################### This is the function call that you will write ###################   
    playerHeadingVec = student_code.calculate_angle_between_vectors([targetPosX-origin_x,targetPosY-origin_y],[450,0])
    
    
    ####################### This is the function call that you will write ###################   
    playerHeadingTrig = student_code.calculate_angles_via_trigonometry(origin_y-targetPosY,radius)
    
    #Write the result of the students calculations
    write_text(screen,"Current angle via scalar-product: " +"{:5.2f}".format(playerHeadingVec),200,75,17)
    write_text(screen,"Current angle via trigonometry: " +"{:5.2f}".format(playerHeadingTrig),600,75,17)
            
		
    pygame.display.flip() # This shows all the updates
    pygame.time.delay(1000) #This puts a delay between each loop iteration    
pygame.quit()
